window.Gleam.initSearch([{"doc":"globlin_fs","title":"globlin_fs","content":"# globlin_fs\n\n[![Package Version](https://img.shields.io/hexpm/v/globlin_fs)](https://hex.pm/packages/globlin_fs)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/globlin_fs/)\n\nThis package adds onto the functionality in the [globlin](https://hexdocs.pm/globlin) package by adding file system globbing. The main reason to keep it separate is to not require `simplifile` in the original `globlin` package so it can be used in the browser.\n\nNote: This library only currently supports Unix file paths. That means it should work on Linux, macOS and BSD.\n\n## Add Dependency\n```sh\ngleam add globlin_fs\n```\n\n## Example\n```gleam\n import gleam/io\n import gleam/list\n import gleam/string\n import globlin\n import globlin_fs\n\n pub fn main() {\n   let assert Ok(pattern) = globlin.new_pattern(&quot;**/*.gleam&quot;)\n   case globlin_fs.glob(pattern, returning: globlin_fs.RegularFiles) {\n     Ok(files) -&gt; {\n       files\n       |&gt; list.sort(string.compare)\n       |&gt; list.each(io.println)\n     }\n     Error(err) -&gt; {\n       io.print(&quot;File error: &quot;)\n       io.debug(err)\n       Nil\n     }\n   }\n }\n ```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/globlin_fs&gt;.\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"globlin_fs","title":"FileError","content":"pub type FileError =\n  simplifile.FileError\n An alias for `simplifile.FileError` needed for the glob methods below.\n\nSynonyms:\ngloblin_fs.FileError\ngloblin_fs FileError","url":"globlin_fs.html#FileError"},{"doc":"globlin_fs","title":"FileType","content":"pub type FileType {\n  RegularFiles\n  Directories\n  AllFiles\n}\n Used to determine which files should be returned by the glob function.\nRegularFiles\n Regular files that are not directories or symlinks.\n\nDirectories\n Directories that are not symlinks.\n\nAllFiles\n Both regular files and directories that are not symlinks.\n\nSynonyms:\ngloblin_fs.FileType\ngloblin_fs FileType","url":"globlin_fs.html#FileType"},{"doc":"globlin_fs","title":"glob","content":"pub fn glob(\n  pattern pattern: Pattern,\n  returning file_type: FileType,\n) -&gt; Result(List(String), FileError)\n Use the specified glob pattern to return a list of the expected file type\n starting from the current working directory.\n \n Note: No order is guaranteed for the resulting path list.\nSynonyms:\ngloblin_fs.glob\ngloblin_fs glob","url":"globlin_fs.html#glob"},{"doc":"globlin_fs","title":"glob_from","content":"pub fn glob_from(\n  pattern pattern: Pattern,\n  directory directory: String,\n  returning file_type: FileType,\n) -&gt; Result(List(String), FileError)\n Use the specified glob pattern to return a list of the expected file type\n starting from the provided directory.\n \n Note: No order is guaranteed for the resulting path list.\nSynonyms:\ngloblin_fs.glob_from\ngloblin_fs glob_from","url":"globlin_fs.html#glob_from"},{"doc":"globlin_fs","title":"globlin_fs","content":"","url":"globlin_fs.html"}]);